@@ -14,25 +14,18 @@
  * limitations under the License.
  */
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
  * @file globus_gass_transfer_proto.h
+ * @brief GASS Transfer Protocol Interface
  *
  * This header defines the GASS protocol module library interface
- *
- * CVS Information:
- *
- * $Source: /home/globdev/CVS/globus-packages/gass/transfer/source/library/globus_gass_transfer_proto.h,v $
- * $Date: 2011/02/03 21:46:40 $
- * $Revision: 1.6 $
- * $Author: bester $
  */
-#endif
 
 /**
- * @defgroup globus_gass_transfer_protocol Protocol Modules
+ * @brief Protocol Implementation API
  *
- * Protocol Implementation API.
+ * @defgroup globus_gass_transfer_protocol Protocol Modules
+ * @ingroup globus_gass_transfer
  *
  * The GASS Protocol Module API is designed to make it possible to
  * extend the GASS client and server APIs to support additional protocols
@@ -44,8 +37,8 @@
  * Every protocol module implementation must include the following
  * header file:
  * @code
- * #include "globus_gass_transfer_proto.h"
- * @endcode
+   #include "globus_gass_transfer_proto.h"
+   @endcode
  *
  * To implement a protocol module, one must create a 
  * #globus_gass_transfer_proto_descriptor_t structure which indicates what
@@ -69,23 +62,15 @@
  * globus_gass_transfer_server server@endlink operations.
  */
 
-#ifndef GLOBUS_GASS_INCLUDE_GLOBUS_GASS_PROTO_H
-#define GLOBUS_GASS_INCLUDE_GLOBUS_GASS_PROTO_H
-
-#ifndef EXTERN_C_BEGIN
-#ifdef __cplusplus
-#define EXTERN_C_BEGIN extern "C" {
-#define EXTERN_C_END }
-#else
-#define EXTERN_C_BEGIN
-#define EXTERN_C_END
-#endif
-#endif
+#ifndef GLOBUS_GASS_PROTO_H
+#define GLOBUS_GASS_PROTO_H
 
 #include "globus_common.h"
 #include "globus_gass_transfer.h"
 
-EXTERN_C_BEGIN
+#ifdef __cplusplus
+"C" {
+#endif
 
 /* Module-specific types */
 /**
@@ -377,9 +362,9 @@ typedef void
 
 /**
  * @struct globus_gass_transfer_request_proto_s
- * Protocol module request handling structure.
- * @ingroup globus_gass_transfer_protocol
+ * @brief Protocol module request handling structure.
  *
+ * @ingroup globus_gass_transfer_protocol
  * This structure is created by a GASS transfer protocol module to
  * handle a particular request. It is created in response to a
  * @link globus_gass_transfer_listener_proto_s::accept
@@ -440,7 +425,7 @@ struct globus_gass_transfer_request_proto_s
 
 /**
  * @struct globus_gass_transfer_listener_proto_s
- * Protocol module listener handling structure.
+ * @brief Protocol module listener handling structure.
  * @ingroup globus_gass_transfer_protocol
  */
 struct globus_gass_transfer_listener_proto_s
@@ -457,7 +442,7 @@ struct globus_gass_transfer_listener_proto_s
 
 /**
  * @struct globus_gass_transfer_proto_descriptor_t
- * Protocol module descriptor structure.
+ * @brief Protocol module descriptor structure.
  *
  * @ingroup globus_gass_transfer_protocol
  * @see globus_gass_transfer_proto_register_protocol(),
@@ -620,6 +605,8 @@ globus_gass_transfer_lf_to_crlf(
 
 #endif
 
-EXTERN_C_END
+#ifdef __cplusplus
+}
+#endif
 
-#endif /* GLOBUS_GASS_INCLUDE_GLOBUS_GASS_PROTO_H */
+#endif /* GLOBUS_GASS_PROTO_H */
