@@ -16,17 +16,11 @@
 
 #ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
- * @file globus_gass_transfer_server.c GASS Server
+ * @file globus_gass_transfer_server.c
+ * @brief GASS Server
  * 
  * This module implements the gass server functionality of the GASS
  * transfer library
- *
- * CVS Information:
- *
- * $Source: /home/globdev/CVS/globus-packages/gass/transfer/source/library/globus_gass_transfer_server.c,v $
- * $Date: 2011/10/20 14:54:45 $
- * $Revision: 1.20 $
- * $Author: bester $
  */
 #endif
 
@@ -114,7 +108,7 @@ globus_gass_transfer_create_listener(
 					   (void *) l,
 					   2);
     globus_list_insert(&globus_i_gass_transfer_listeners,
-		       (void *) (*listener));
+		       (void *) (intptr_t) (*listener));
     
     rc = protocol->new_listener(*listener,
 				attr,
@@ -927,7 +921,7 @@ globus_i_gass_transfer_close_listener(
 	    GLOBUS_NULL,
 	    &delay_time,
 	    globus_l_gass_transfer_callback_close_callback,
-	    (void *) listener);
+	    (void *) (intptr_t) listener);
 
 	break;
 
@@ -970,7 +964,7 @@ globus_l_gass_transfer_callback_close_callback(
     globus_gass_transfer_close_callback_t	callback;
     void *					callback_arg;
 
-    listener = (globus_gass_transfer_listener_t) arg;
+    listener = (globus_gass_transfer_listener_t) (intptr_t) arg;
 
     l = (globus_gass_transfer_listener_struct_t *) arg;
 
@@ -1017,7 +1011,7 @@ globus_i_gass_transfer_listener_destroy(
 	globus_list_t *				tmp;
 
 	tmp = globus_list_search(globus_i_gass_transfer_listeners,
-				 (void *) listener);
+				 (void *) (intptr_t) listener);
 
 	globus_list_remove(&globus_i_gass_transfer_listeners,
 			   tmp);
